
/**
 * A representation of a car which can change color, supports
 * dragging, and which can turn its headlights on or off.
 * 
 * @author Jim Teresco 
 */

import objectdraw.*;
import java.awt.*;

public class Car
{

    private static final int BODY_LENGTH = 150;
    private static final int BODY_HEIGHT = 35;
    private static final int CABIN_HEIGHT = 40;
    private static final int CABIN_LENGTH = BODY_LENGTH/2;
    private static final int CABIN_OFFSET = (BODY_LENGTH-CABIN_LENGTH)/2;
    private static final int TIRE_SIZE = 40;
    private static final int TIRE_OFFSET_X = BODY_LENGTH/4;
    private static final int TIRE_OFFSET_Y = CABIN_HEIGHT + BODY_HEIGHT - TIRE_SIZE/2;
    private static final int HEADLIGHT_HEIGHT = BODY_HEIGHT/2;
    private static final int HEADLIGHT_WIDTH = HEADLIGHT_HEIGHT/3;
    
    private FilledRect body;
    private FilledArc cabin;
    private FilledOval frontTire, rearTire, headlight;
    
    // construct a car
    public Car(double x, double y, Color color, DrawingCanvas canvas) {
        
        rearTire = new FilledOval(x + TIRE_OFFSET_X - TIRE_SIZE/2, y + TIRE_OFFSET_Y, TIRE_SIZE, TIRE_SIZE, canvas);
        frontTire = new FilledOval(x + BODY_LENGTH - TIRE_OFFSET_X - TIRE_SIZE/2, y + TIRE_OFFSET_Y, TIRE_SIZE, TIRE_SIZE, canvas);
        body = new FilledRect(x, y + CABIN_HEIGHT, BODY_LENGTH, BODY_HEIGHT, canvas);
        body.setColor(color);
        cabin = new FilledArc(x + CABIN_OFFSET, y, CABIN_LENGTH, CABIN_HEIGHT*2, 0, 180, canvas);
        cabin.setColor(color);
        headlight = new FilledOval(x + BODY_LENGTH - HEADLIGHT_WIDTH/2, y + CABIN_HEIGHT, HEADLIGHT_WIDTH, HEADLIGHT_HEIGHT, canvas);
        
    }
    
    // check containment
    public boolean contains(Location point) {
        
        return body.contains(point) || cabin.contains(point) ||
            frontTire.contains(point) || rearTire.contains(point) ||
            headlight.contains(point);
    }
    
    public void move(double xChange, double yChange) {
        
        body.move(xChange, yChange);
        cabin.move(xChange, yChange);
        frontTire.move(xChange, yChange);
        rearTire.move(xChange, yChange);
        headlight.move(xChange, yChange);
        
    }
    
    // center of the car
    public Location getCenter() {
        
        return new Location(body.getX() + BODY_LENGTH/2, body.getY());
    }
        
    // headlight control
    public void turnOffHeadlights() {
        headlight.setColor(Color.black);
    }
    
    public void turnOnHeadlights() {
        headlight.setColor(Color.yellow);
    }
    
    // get headlight status
    public boolean headlightsOn() {
        
        return headlight.getColor().equals(Color.yellow);
    }
    
    // set car color
    public void setColor(Color newColor) {
        
        body.setColor(newColor);
        cabin.setColor(newColor);
    }
}
